.github/pkgdown/extra.css
R/utils.R
check_installed.Rd
check_installed() errors with an actionable installation hint when a package that is only listed under Suggests is needed but unavailable.
check_installed()
Suggests
check_installed(package, reason = NULL)
The name of the package to check.
A short description of what the package is needed for.
invisible(TRUE), or an error if the package is missing.
invisible(TRUE)