extract_protein_list() extracts the protein lists from the upset data.
It creates a list with the proteins for each combination of diseases.
It also creates a tibble with the proteins for each combination of diseases.
.github/pkgdown/extra.css
Skip to contentsextract_protein_list() extracts the protein lists from the upset data.
It creates a list with the proteins for each combination of diseases.
It also creates a tibble with the proteins for each combination of diseases.